@@ -185,7 +185,7 @@ StructType *getOrCreateOpaqueStructType(Module *M, StringRef Name) {
 }
 
 void getFunctionTypeParameterTypes(llvm::FunctionType *FT,
-                                   SmallVector<Type *> &ArgTys) {
+                                   std::vector<Type *> &ArgTys) {
   for (auto I = FT->param_begin(), E = FT->param_end(); I != E; ++I) {
     ArgTys.push_back(*I);
   }
@@ -605,21 +605,6 @@ static Type *parsePrimitiveType(LLVMContext &Ctx, StringRef Name) {
 
 } // namespace SPIRV
 
-namespace {
-
-// Return the value for when the dimension index of a builtin is out of range.
-uint64_t getBuiltinOutOfRangeValue(StringRef VarName) {
-  assert(VarName.starts_with("__spirv_BuiltIn"));
-  return StringSwitch<uint64_t>(VarName)
-      .EndsWith("GlobalSize", 1)
-      .EndsWith("NumWorkgroups", 1)
-      .EndsWith("WorkgroupSize", 1)
-      .EndsWith("EnqueuedWorkgroupSize", 1)
-      .Default(0);
-}
-
-} // anonymous namespace
-
 // The demangler node hierarchy doesn't use LLVM's RTTI helper functions (as it
 // also needs to live in libcxxabi). By specializing this implementation here,
 // we can add support for these functions.
@@ -1330,8 +1315,6 @@ static SPIR::RefParamType transTypeDesc(Type *Ty,
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_FLOAT));
   if (Ty->isDoubleTy())
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_DOUBLE));
-  if (Ty->isBFloatTy())
-    return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_BFLOAT));
   if (auto *VecTy = dyn_cast<FixedVectorType>(Ty)) {
     return SPIR::RefParamType(new SPIR::VectorType(
         transTypeDesc(VecTy->getElementType(), Info), VecTy->getNumElements()));
@@ -2153,50 +2136,22 @@ bool lowerBuiltinCallsToVariables(Module *M) {
     bool IsVec = F.getFunctionType()->getNumParams() > 0;
     Type *GVType =
         IsVec ? FixedVectorType::get(F.getReturnType(), 3) : F.getReturnType();
-    GlobalVariable *BV = nullptr;
-    // Consider the following LLVM IR:
-    // @__spirv_BuiltInLocalInvocationId = <Global constant>
-    // .....
-    // define spir_kernel void @kernel1(....) {
-    //   %3 = tail call i64 @_Z12get_local_idj(i32 0)
-    //   .....
-    //   return void
-    // }
-    // During the OCLToSPIRV pass, the opencl call will get lowered to
-    // yet another global variable with the name
-    // '@__spirv_BuiltInLocalInvocationId'. In such a case, we would want to
-    // create only a single global variable with this name.
-    if (GlobalVariable *GV = M->getGlobalVariable(BuiltinVarName))
-      BV = GV;
-    else
-      BV = new GlobalVariable(*M, GVType, /*isConstant=*/true,
-                              GlobalValue::ExternalLinkage, nullptr,
-                              BuiltinVarName, 0, GlobalVariable::NotThreadLocal,
-                              SPIRAS_Input);
+    auto *BV = new GlobalVariable(
+        *M, GVType, /*isConstant=*/true, GlobalValue::ExternalLinkage, nullptr,
+        BuiltinVarName, 0, GlobalVariable::NotThreadLocal, SPIRAS_Input);
     for (auto *U : F.users()) {
       auto *CI = dyn_cast<CallInst>(U);
       assert(CI && "invalid instruction");
-      IRBuilder<> Builder(CI);
-      Value *NewValue = Builder.CreateLoad(GVType, BV);
+      const DebugLoc &DLoc = CI->getDebugLoc();
+      Instruction *NewValue = new LoadInst(GVType, BV, "", CI);
+      if (DLoc)
+        NewValue->setDebugLoc(DLoc);
       LLVM_DEBUG(dbgs() << "Transform: " << *CI << " => " << *NewValue << '\n');
       if (IsVec) {
-        auto *GVVecTy = cast<FixedVectorType>(GVType);
-        ConstantInt *Bound = Builder.getInt32(GVVecTy->getNumElements());
-        // Create a select on the index first, to avoid undefined behaviour
-        // due to exceeding the vector size by the extractelement.
-        Value *IndexCmp = Builder.CreateICmpULT(CI->getArgOperand(0), Bound);
-        Constant *ZeroIndex =
-            ConstantInt::get(CI->getArgOperand(0)->getType(), 0);
-        Value *ExtractIndex =
-            Builder.CreateSelect(IndexCmp, CI->getArgOperand(0), ZeroIndex);
-
-        // Extract from builtin variable.
-        NewValue = Builder.CreateExtractElement(NewValue, ExtractIndex);
-
-        // Clamp to out-of-range value.
-        Constant *OutOfRangeVal = ConstantInt::get(
-            F.getReturnType(), getBuiltinOutOfRangeValue(BuiltinVarName));
-        NewValue = Builder.CreateSelect(IndexCmp, NewValue, OutOfRangeVal);
+        NewValue =
+            ExtractElementInst::Create(NewValue, CI->getArgOperand(0), "", CI);
+        if (DLoc)
+          NewValue->setDebugLoc(DLoc);
         LLVM_DEBUG(dbgs() << *NewValue << '\n');
       }
       NewValue->takeName(CI);
@@ -2233,24 +2188,11 @@ bool postProcessBuiltinReturningStruct(Function *F) {
   SmallVector<Instruction *, 32> InstToRemove;
   for (auto *U : F->users()) {
     if (auto *CI = dyn_cast<CallInst>(U)) {
-      IRBuilder<> Builder(CI->getParent());
-      Builder.SetInsertPoint(CI);
-      SmallVector<User *> Users(CI->users());
-      Value *A = nullptr;
-      StoreInst *SI = nullptr;
-      for (auto *U : Users) {
-        if ((SI = dyn_cast<StoreInst>(U)) != nullptr) {
-          A = SI->getPointerOperand();
-          InstToRemove.push_back(SI);
-          break;
-        }
-      }
-      if (!A) {
-        A = Builder.CreateAlloca(F->getReturnType());
-      }
-      SmallVector<Type *> ArgTys;
+      auto *ST = cast<StoreInst>(*(CI->user_begin()));
+      std::vector<Type *> ArgTys;
       getFunctionTypeParameterTypes(F->getFunctionType(), ArgTys);
-      ArgTys.insert(ArgTys.begin(), A->getType());
+      ArgTys.insert(ArgTys.begin(),
+                    PointerType::get(F->getReturnType(), SPIRAS_Private));
       auto *NewF =
           getOrCreateFunction(M, Type::getVoidTy(*Context), ArgTys, Name);
       auto SretAttr = Attribute::get(*Context, Attribute::AttrKind::StructRet,
@@ -2258,20 +2200,11 @@ bool postProcessBuiltinReturningStruct(Function *F) {
       NewF->addParamAttr(0, SretAttr);
       NewF->setCallingConv(F->getCallingConv());
       auto Args = getArguments(CI);
-      Args.insert(Args.begin(), A);
-      CallInst *NewCI = Builder.CreateCall(
-          NewF, Args, NewF->getReturnType()->isVoidTy() ? "" : CI->getName());
+      Args.insert(Args.begin(), ST->getPointerOperand());
+      auto *NewCI = CallInst::Create(NewF, Args, CI->getName(), CI);
       NewCI->addParamAttr(0, SretAttr);
       NewCI->setCallingConv(CI->getCallingConv());
-      SmallVector<User *, 32> UsersToReplace;
-      for (auto *U : Users)
-        if (U != SI)
-          UsersToReplace.push_back(U);
-      if (UsersToReplace.size() > 0) {
-        auto *LI = Builder.CreateLoad(F->getReturnType(), A);
-        for (auto *U : UsersToReplace)
-          U->replaceUsesOfWith(CI, LI);
-      }
+      InstToRemove.push_back(ST);
       InstToRemove.push_back(CI);
     }
   }
@@ -2521,7 +2454,6 @@ public:
     }
     case internal::OpConvertHandleToImageINTEL:
     case internal::OpConvertHandleToSamplerINTEL:
-    case internal::OpConvertHandleToSampledImageINTEL:
       addUnsignedArg(0);
       break;
     default:;
